@@ -15,8 +15,13 @@ XML_API = "http://www.zdf.de/ZDFmediathek/xmlservice/web/beitragsDetails?id=%i"
 CHUNK_SIZE = 1024*256 # 256 KB
 
 def video_key(video):
+    bitrate = 0
+
+    if "videoBitrate" in video:
+        bitrate = int(video.videoBitrate.text)
+
     return (
-        int(video.videoBitrate.text),
+        bitrate,
         video.find("facets") is not None and any((f.text == "progressive" for f in video.facets.facet))
     )
 
@@ -87,4 +92,4 @@ def main():
     return 0
 
 if __name__ == "__main__":
-    sys.exit(main())
\ No newline at end of file
+    sys.exit(main())
